@@ -1,15 +1,18 @@
 """Main SQL persistence module, shared between USDA and NT databases"""
 import sqlite3
-
+from collections.abc import Sequence
 
 # ------------------------------------------------
 # Entry fetching methods
 # ------------------------------------------------
+from ntclient import CLI_CONFIG
+
+
 def sql_entries(sql_result: sqlite3.Cursor) -> list:
     """Formats and returns a `sql_result()` for console digestion and output"""
     # TODO: return object: metadata, command, status, errors, etc?
-    rows = sql_result.fetchall()
 
+    rows = sql_result.fetchall()
     return rows
 
 
@@ -29,12 +32,13 @@ def version(con: sqlite3.Connection) -> str:
 
     cur = con.cursor()
     result = cur.execute("SELECT * FROM version;").fetchall()
+
     close_con_and_cur(con, cur, commit=False)
-    return result[-1][1]
+    return str(result[-1][1])
 
 
 def close_con_and_cur(
-    con: sqlite3.Connection, cur: sqlite3.Cursor, commit=True
+    con: sqlite3.Connection, cur: sqlite3.Cursor, commit: bool = True
 ) -> None:
     """Cleans up, commits, and closes after an SQL command is run"""
 
@@ -48,15 +52,21 @@ def close_con_and_cur(
 # Main query methods
 # ------------------------------------------------
 def _prep_query(
-    con: sqlite3.Connection, query: str, db_name: str, values=None
-) -> tuple:
-    """@param values: tuple | list"""
-
-    from ntclient import DEBUG  # pylint: disable=import-outside-toplevel
+    con: sqlite3.Connection, query: str, db_name: str, values: Sequence = ()
+) -> sqlite3.Cursor:
+    """
+    Run a query and return a cursor object ready for row extraction.
+    @param con: sqlite3.Connection object
+    @param query: query string, e.g. SELECT * FROM version;
+    @param db_name: (nt | usda) database name [TODO: enum]
+    @param values: (tuple | list)
+        empty for bare queries, tuple for single, and list for many
+    @return: A sqlite3.Cursor object with populated return values.
+    """
 
     cur = con.cursor()
 
-    if DEBUG:
+    if CLI_CONFIG.debug:
         print("%s.sqlite3: %s" % (db_name, query))
         if values:
             # TODO: better debug logging, more "control-findable",
@@ -66,24 +76,24 @@ def _prep_query(
     # TODO: separate `entry` & `entries` entity for single vs. bulk insert?
     if values:
         if isinstance(values, list):
-            result = cur.executemany(query, values)
+            cur.executemany(query, values)
         else:  # tuple
-            result = cur.execute(query, values)
+            cur.execute(query, values)
     else:
-        result = cur.execute(query)
+        cur.execute(query)
 
-    return cur, result
+    return cur
 
 
 def _sql(
     con: sqlite3.Connection,
     query: str,
     db_name: str,
-    values=None,
+    values: Sequence = (),
 ) -> list:
     """@param values: tuple | list"""
 
-    cur, result = _prep_query(con, query, db_name, values)
+    cur = _prep_query(con, query, db_name, values)
 
     # TODO: print "<number> SELECTED", or other info
     #  BASED ON command SELECT/INSERT/DELETE/UPDATE
@@ -97,13 +107,13 @@ def _sql_headers(
     con: sqlite3.Connection,
     query: str,
     db_name: str,
-    values=None,
+    values: Sequence = (),
 ) -> tuple:
     """@param values: tuple | list"""
 
-    cur, result = _prep_query(con, query, db_name, values)
+    cur = _prep_query(con, query, db_name, values)
 
-    result = sql_entries_headers(result)
+    result = sql_entries_headers(cur)
 
     close_con_and_cur(con, cur)
     return result
