@@ -3,66 +3,48 @@
 Created on Sun Nov 11 23:57:03 2018
 
 @author: shane
-
-This file is part of nutra, a nutrient analysis program.
-    https://github.com/nutratech/cli
-    https://pypi.org/project/nutra/
-
-nutra is an extensible nutrient analysis and composition application.
-Copyright (C) 2018-2021  Shane Jaroch
-
-This program is free software: you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <https://www.gnu.org/licenses/>.
 """
 
 import csv
-import shutil
 from collections import OrderedDict
 
-from colorama import Fore, Style
 from tabulate import tabulate
 
+from ntclient import (
+    BUFFER_WD,
+    CLI_CONFIG,
+    NUTR_ID_CARBS,
+    NUTR_ID_FAT_TOT,
+    NUTR_ID_FIBER,
+    NUTR_ID_KCAL,
+    NUTR_ID_PROTEIN,
+)
 from ntclient.persistence.sql.usda.funcs import (
     sql_analyze_foods,
     sql_food_details,
     sql_nutrients_overview,
     sql_servings,
 )
-from ntclient.utils import (
-    COLOR_CRIT,
-    COLOR_DEFAULT,
-    COLOR_OVER,
-    COLOR_WARN,
-    NUTR_ID_CARBS,
-    NUTR_ID_FAT_TOT,
-    NUTR_ID_FIBER,
-    NUTR_ID_KCAL,
-    NUTR_ID_PROTEIN,
-    THRESH_CRIT,
-    THRESH_OVER,
-    THRESH_WARN,
-)
 
 
-def foods_analyze(food_ids, grams=None):
-    """Analyze a list of food_ids against stock RDA values"""
-    # TODO: from ntclient.utils.nutprogbar import nutprogbar
+################################################################################
+# Foods
+################################################################################
+def foods_analyze(food_ids: set, grams: float = 0) -> tuple:
+    """
+    Analyze a list of food_ids against stock RDA values
+    TODO: from ntclient.utils.nutprogbar import nutprogbar
+    TODO: support -t (tabular/non-visual) output flag
+    """
+
+    ################################################################################
     # Get analysis
+    ################################################################################
     raw_analyses = sql_analyze_foods(food_ids)
     analyses = {}
     for analysis in raw_analyses:
         food_id = analysis[0]
-        if grams is not None:
+        if grams:
             anl = (analysis[1], round(analysis[2] * grams / 100, 2))
         else:
             anl = (analysis[1], analysis[2])
@@ -70,21 +52,20 @@ def foods_analyze(food_ids, grams=None):
             analyses[food_id] = [anl]
         else:
             analyses[food_id].append(anl)
-    # serving = servings()[1]
+
     serving = sql_servings(food_ids)
-    food_des = sql_food_details(food_ids)
-    food_des = {x[0]: x for x in food_des}
+    food_des_rows = sql_food_details(food_ids)
+    food_des = {x[0]: x for x in food_des_rows}
     nutrients = sql_nutrients_overview()
     rdas = {x[0]: x[1] for x in nutrients.values()}
 
-    # --------------------------------------
+    ################################################################################
     # Food-by-food analysis (w/ servings)
-    # --------------------------------------
-    servings_tables = []
-    nutrients_tables = []
-    for food_id in analyses:
+    ################################################################################
+    servings_rows = []
+    nutrients_rows = []
+    for food_id, nut_val_tuples in analyses.items():
         food_name = food_des[food_id][2]
-        # food_name = food["long_desc"]
         print(
             "\n======================================\n"
             + "==> {0} ({1})\n".format(food_name, food_id)
@@ -92,17 +73,15 @@ def foods_analyze(food_ids, grams=None):
         )
         print("\n=========================\nSERVINGS\n=========================\n")
 
-        ###############
+        ################################################################################
         # Serving table
+        ################################################################################
         headers = ["msre_id", "msre_desc", "grams"]
-        # Copy obj with dict(x)
-        rows = [(x[1], x[2], x[3]) for x in serving if x[0] == food_id]
-        # for r in rows:
-        #     r.pop("food_id")
+        serving_rows = [(x[1], x[2], x[3]) for x in serving if x[0] == food_id]
         # Print table
-        servings_table = tabulate(rows, headers=headers, tablefmt="presto")
+        servings_table = tabulate(serving_rows, headers=headers, tablefmt="presto")
         print(servings_table)
-        servings_tables.append(servings_table)
+        servings_rows.append(serving_rows)
 
         refuse = next(
             ((x[7], x[8]) for x in food_des.values() if x[0] == food_id and x[7]), None
@@ -114,50 +93,49 @@ def foods_analyze(food_ids, grams=None):
 
         print("\n=========================\nNUTRITION\n=========================\n")
 
-        ################
+        ################################################################################
         # Nutrient table
+        ################################################################################
         headers = ["id", "nutrient", "rda", "amount", "units"]
-        rows = []
-        # food_nutes = {x["nutr_id"]: x for x in food["nutrients"]}
-        # for id, nute in food_nutes.items():
-        for food_id_2, amount in analyses[food_id]:
+        nutrient_rows = []
+        for nutrient_id, amount in nut_val_tuples:
             # Skip zero values
-            # amount = food_nutes[id]["nutr_val"]
             if not amount:
                 continue
 
-            nutr_desc = (
-                nutrients[food_id_2][4]
-                if nutrients[food_id_2][4]
-                else nutrients[food_id_2][3]
-            )
-            unit = nutrients[food_id_2][2]
+            nutr_desc = nutrients[nutrient_id][4] or nutrients[nutrient_id][3]
+            unit = nutrients[nutrient_id][2]
 
             # Insert RDA % into row
-            if rdas[food_id_2]:
-                rda_perc = str(round(amount / rdas[food_id_2] * 100, 1)) + "%"
+            if rdas[nutrient_id]:
+                rda_perc = str(round(amount / rdas[nutrient_id] * 100, 1)) + "%"
             else:
-                # print(rdas[id])
                 rda_perc = None
-            row = [food_id_2, nutr_desc, rda_perc, round(amount, 2), unit]
+            row = [nutrient_id, nutr_desc, rda_perc, round(amount, 2), unit]
 
-            rows.append(row)
+            nutrient_rows.append(row)
 
+        ################################################################################
         # Print table
-        table = tabulate(rows, headers=headers, tablefmt="presto")
+        ################################################################################
+        table = tabulate(nutrient_rows, headers=headers, tablefmt="presto")
         print(table)
-        nutrients_tables.append(table)
+        nutrients_rows.append(nutrient_rows)
 
-    return nutrients_tables, servings_tables
+    return 0, nutrients_rows, servings_rows
 
 
-def day_analyze(day_csv_paths, rda_csv_path=None, debug=False):
+################################################################################
+# Day
+################################################################################
+def day_analyze(day_csv_paths: list, rda_csv_path: str = str()) -> tuple:
     """Analyze a day optionally with custom RDAs,
     e.g.  nutra day ~/.nutra/rocky.csv -r ~/.nutra/dog-rdas-18lbs.csv
     TODO: Should be a subset of foods_analyze
     """
-    if rda_csv_path is not None:
-        with open(rda_csv_path) as file_path:
+
+    if rda_csv_path:
+        with open(rda_csv_path, encoding="utf-8") as file_path:
             rda_csv_input = csv.DictReader(
                 row for row in file_path if not row.startswith("#")
             )
@@ -168,7 +146,7 @@ def day_analyze(day_csv_paths, rda_csv_path=None, debug=False):
     logs = []
     food_ids = set()
     for day_csv_path in day_csv_paths:
-        with open(day_csv_path) as file_path:
+        with open(day_csv_path, encoding="utf-8") as file_path:
             rows = [row for row in file_path if not row.startswith("#")]
             day_csv_input = csv.DictReader(rows)
             log = list(day_csv_input)
@@ -178,17 +156,17 @@ def day_analyze(day_csv_paths, rda_csv_path=None, debug=False):
         logs.append(log)
 
     # Inject user RDAs
-    nutrients = [tuple(x) for x in sql_nutrients_overview().values()]
+    nutrients_lists = [list(x) for x in sql_nutrients_overview().values()]
     for rda in rdas:
         nutrient_id = int(rda["id"])
         _rda = float(rda["rda"])
-        for nutrient in nutrients:
-            if nutrient[0] == nutrient_id:
-                nutrient[1] = _rda
-                if debug:
-                    substr = "{0} {1}".format(_rda, nutrient[2]).ljust(12)
-                    print("INJECT RDA: {0} -->  {1}".format(substr, nutrient[4]))
-    nutrients = {x[0]: x for x in nutrients}
+        for _nutrient in nutrients_lists:
+            if _nutrient[0] == nutrient_id:
+                _nutrient[1] = _rda
+                if CLI_CONFIG.debug:
+                    substr = "{0} {1}".format(_rda, _nutrient[2]).ljust(12)
+                    print("INJECT RDA: {0} -->  {1}".format(substr, _nutrient[4]))
+    nutrients = {x[0]: x for x in nutrients_lists}
 
     # Analyze foods
     foods_analysis = {}
@@ -203,14 +181,14 @@ def day_analyze(day_csv_paths, rda_csv_path=None, debug=False):
     # Compute totals
     nutrients_totals = []
     for log in logs:
-        nutrient_totals = OrderedDict()
+        nutrient_totals = OrderedDict()  # dict()/{} is NOT ORDERED before 3.6/3.7
         for entry in log:
             if entry["id"]:
                 food_id = int(entry["id"])
                 grams = float(entry["grams"])
-                for nutrient in foods_analysis[food_id]:
-                    nutr_id = nutrient[0]
-                    nutr_per_100g = nutrient[1]
+                for _nutrient2 in foods_analysis[food_id]:
+                    nutr_id = _nutrient2[0]
+                    nutr_per_100g = _nutrient2[1]
                     nutr_val = grams / 100 * nutr_per_100g
                     if nutr_id not in nutrient_totals:
                         nutrient_totals[nutr_id] = nutr_val
@@ -220,80 +198,80 @@ def day_analyze(day_csv_paths, rda_csv_path=None, debug=False):
 
     #######
     # Print
-    term_width = shutil.get_terminal_size()[0]
-    buffer = term_width - 4 if term_width > 4 else term_width
+    buffer = BUFFER_WD - 4 if BUFFER_WD > 4 else BUFFER_WD
     for analysis in nutrients_totals:
         day_format(analysis, nutrients, buffer=buffer)
-    return nutrients_totals
+    return 0, nutrients_totals
 
 
-def day_format(analysis, nutrients, buffer=None):
+# TODO: why not this...? nutrients: Mapping[int, tuple]
+def day_format(analysis: dict, nutrients: dict, buffer: int = 0) -> None:
     """Formats day analysis for printing to console"""
 
-    def print_header(header):
-        print(Fore.CYAN, end="")
+    def print_header(header: str) -> None:
+        print(CLI_CONFIG.color_default, end="")
         print("~~~~~~~~~~~~~~~~~~~~~~~~~~~")
         print("--> %s" % header)
         print("~~~~~~~~~~~~~~~~~~~~~~~~~~~")
-        print(Style.RESET_ALL)
+        print(CLI_CONFIG.style_reset_all)
 
-    def print_macro_bar(fat, net_carb, pro, kcals_max, buffer=None):
-        kcals = fat * 9 + net_carb * 4 + pro * 4
+    def print_macro_bar(
+        _fat: float, _net_carb: float, _pro: float, _kcals_max: float, _buffer: int = 0
+    ) -> None:
+        _kcals = fat * 9 + net_carb * 4 + _pro * 4
 
-        p_fat = (fat * 9) / kcals
-        p_carb = (net_carb * 4) / kcals
-        p_pro = (pro * 4) / kcals
+        p_fat = (_fat * 9) / _kcals
+        p_car = (_net_carb * 4) / _kcals
+        p_pro = (_pro * 4) / _kcals
 
         # TODO: handle rounding cases, tack on to, or trim off FROM LONGEST ?
-        mult = kcals / kcals_max
-        n_fat = round(p_fat * buffer * mult)
-        n_carb = round(p_carb * buffer * mult)
-        n_pro = round(p_pro * buffer * mult)
+        mult = _kcals / _kcals_max
+        n_fat = round(p_fat * _buffer * mult)
+        n_car = round(p_car * _buffer * mult)
+        n_pro = round(p_pro * _buffer * mult)
 
         # Headers
         f_buf = " " * (n_fat // 2) + "Fat" + " " * (n_fat - n_fat // 2 - 3)
-        c_buf = " " * (n_carb // 2) + "Carbs" + " " * (n_carb - n_carb // 2 - 5)
+        c_buf = " " * (n_car // 2) + "Carbs" + " " * (n_car - n_car // 2 - 5)
         p_buf = " " * (n_pro // 2) + "Pro" + " " * (n_pro - n_pro // 2 - 3)
         print(
             "  "
-            + Fore.YELLOW
+            + CLI_CONFIG.color_yellow
             + f_buf
-            + Fore.BLUE
+            + CLI_CONFIG.color_blue
             + c_buf
-            + Fore.RED
+            + CLI_CONFIG.color_red
             + p_buf
-            + Style.RESET_ALL
+            + CLI_CONFIG.style_reset_all
         )
 
         # Bars
         print(" <", end="")
-        print(Fore.YELLOW + "=" * n_fat, end="")
-        print(Fore.BLUE + "=" * n_carb, end="")
-        print(Fore.RED + "=" * n_pro, end="")
-        print(Style.RESET_ALL + ">")
+        print(CLI_CONFIG.color_yellow + "=" * n_fat, end="")
+        print(CLI_CONFIG.color_blue + "=" * n_car, end="")
+        print(CLI_CONFIG.color_red + "=" * n_pro, end="")
+        print(CLI_CONFIG.style_reset_all + ">")
 
         # Calorie footers
         k_fat = str(round(fat * 9))
-        k_carb = str(round(net_carb * 4))
+        k_car = str(round(net_carb * 4))
         k_pro = str(round(pro * 4))
         f_buf = " " * (n_fat // 2) + k_fat + " " * (n_fat - n_fat // 2 - len(k_fat))
-        c_buf = (
-            " " * (n_carb // 2) + k_carb + " " * (n_carb - n_carb // 2 - len(k_carb))
-        )
+        c_buf = " " * (n_car // 2) + k_car + " " * (n_car - n_car // 2 - len(k_car))
         p_buf = " " * (n_pro // 2) + k_pro + " " * (n_pro - n_pro // 2 - len(k_pro))
         print(
             "  "
-            + Fore.YELLOW
+            + CLI_CONFIG.color_yellow
             + f_buf
-            + Fore.BLUE
+            + CLI_CONFIG.color_blue
             + c_buf
-            + Fore.RED
+            + CLI_CONFIG.color_red
             + p_buf
-            + Style.RESET_ALL
+            + CLI_CONFIG.style_reset_all
         )
 
-    def print_nute_bar(n_id, amount, nutrients):
-        nutrient = nutrients[n_id]
+    def print_nute_bar(_n_id: int, amount: float, _nutrients: dict) -> tuple:
+        nutrient = _nutrients[_n_id]
         rda = nutrient[1]
         tag = nutrient[3]
         unit = nutrient[2]
@@ -304,14 +282,14 @@ def day_format(analysis, nutrients, buffer=None):
         attain = amount / rda
         perc = round(100 * attain, 1)
 
-        if attain >= THRESH_OVER:
-            color = COLOR_OVER
-        elif attain <= THRESH_CRIT:
-            color = COLOR_CRIT
-        elif attain <= THRESH_WARN:
-            color = COLOR_WARN
+        if attain >= CLI_CONFIG.thresh_over:
+            color = CLI_CONFIG.color_over
+        elif attain <= CLI_CONFIG.thresh_crit:
+            color = CLI_CONFIG.color_crit
+        elif attain <= CLI_CONFIG.thresh_warn:
+            color = CLI_CONFIG.color_warn
         else:
-            color = COLOR_DEFAULT
+            color = CLI_CONFIG.color_default
 
         # Print
         detail_amount = "{0}/{1} {2}".format(round(amount, 1), rda, unit).ljust(18)
@@ -321,7 +299,7 @@ def day_format(analysis, nutrients, buffer=None):
         print(" {0}<".format(color), end="")
         print("=" * left_pos + " " * (left_index - left_pos) + ">", end="")
         print(" {0}%\t[{1}]".format(perc, detail_amount), end="")
-        print(Style.RESET_ALL)
+        print(CLI_CONFIG.style_reset_all)
 
         return True, perc
 
@@ -347,7 +325,7 @@ def day_format(analysis, nutrients, buffer=None):
             kcals, rda_perc, kcals_449
         )
     )
-    print_macro_bar(fat, net_carb, pro, kcals_max, buffer=buffer)
+    print_macro_bar(fat, net_carb, pro, kcals_max, _buffer=buffer)
     print(
         "\nDesired:   {0} kcal ({1} kcal)".format(
             kcals_rda, "%+d" % (kcals - kcals_rda)
@@ -358,7 +336,7 @@ def day_format(analysis, nutrients, buffer=None):
         net_carb_rda,
         pro_rda,
         kcals_max,
-        buffer=buffer,
+        _buffer=buffer,
     )
 
     # Nutrition detail report
@@ -367,5 +345,6 @@ def day_format(analysis, nutrients, buffer=None):
         print_nute_bar(n_id, analysis[n_id], nutrients)
     # TODO: below
     print(
-        "work in progress...some minor fields with negligible data, they are not shown here"
+        "work in progress... "
+        "some minor fields with negligible data, they are not shown here"
     )
